<?php
if (!isset($gCms)) exit;
if (! $this->CheckPermission('Modify Templates')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

$db = $gCms->GetDb();

if (isset($params['submit']))
	{
	$query = 'update '.cms_db_prefix().
		      'module_dectree_trees set template=? where tree_id = ?';
	$result = $db->Execute($query,array($params['template'],$params['tree_id']));
	$params = array('tab_message'=> 'template_updated', 'active_tab' => 'listing');
	$this->DoAction('defaultadmin', $id, $params, $returnid);
	return;
	}

$query = 'SELECT * from '.cms_db_prefix().
      'module_dectree_trees where tree_id = ?';
$result = $db->Execute($query,array($params['tree_id']));
$row=$result->FetchRow();

$smarty->assign('tree',$row);
$smarty->assign('start_form', $this->CreateFormStart($id, 'admin_edit_template', $returnid));
$smarty->assign('title_tree_description',$this->Lang('title_tree_description'));
$smarty->assign('title_template',$this->Lang('title_template'));

$smarty->assign('input_template',$this->CreateTextArea(false, $id,
	 (empty($row['template'])?$this->GetPreference('default_template'):$row['template']),
	'template', '', '', '', '', '80', '25'));

$smarty->assign('submit', $this->CreateInputHidden($id,'tree_id',$params['tree_id']).$this->CreateInputSubmit($id, 'submit', $this->Lang('submit')));
$smarty->assign('end_form', $this->CreateFormEnd());

echo $this->ProcessTemplate('add_edit.tpl');
?>